@@ -196,6 +196,19 @@ AccessLog *HttpLog::getAccessLog()
 
 int HttpLog::setErrorLogFile(const char *pFileName)
 {
+    const char *excludeList[] = { ".php", ".cgi", ".pl", ".shtml" };
+    int len = strlen(pFileName);
+    for (int i=0; i<sizeof(excludeList)/ sizeof(char *); ++i)
+    {
+        int ll = strlen(excludeList[i]);
+        if (len > ll &&
+            strncasecmp(pFileName + len - ll, excludeList[i], ll) == 0)
+        {
+            HttpLog::perror("Cannot use this suffix as errorlog", pFileName);
+            return LS_FAIL;
+        }
+    }
+    
     Appender *appender
         = Appender::getAppender(pFileName, "appender.ps");
     if (appender)
