@@ -43,6 +43,9 @@ HttpServerConfig::HttpServerConfig()
     , m_iCompressLevel(4)
     , m_iBrCompress(0)
     , m_iEnableLve(0)
+    , m_iUsePagespeed(0)
+    , m_iCheckDeniedSymLink(0)
+    , m_iEnableMultiCerts(0)
     , m_iMaxFcgiInstances(2000)
     , m_iMaxTempFileSize(10240)
     , m_iConnTimeout(300)
